<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>About</name>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-family:&apos;Sans Serif&apos;; font-size:12pt; font-style:normal;&quot;&gt;&lt;p style=&quot;margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Version: %1&lt;br/&gt;Qt version: %5&lt;br/&gt;Drumstick version: %6&lt;br/&gt;Build date: %2&lt;br/&gt;Build time: %3&lt;br/&gt;Compiler: %4&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AboutClass</name>
    <message>
        <source>About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Drumstick Metronome&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Noto Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;a href=&quot;https://kmetronome.sourceforge.io&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#007af4;&quot;&gt;https://kmetronome.sourceforge.io&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Noto Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;;&quot;&gt;Copyright © 2002-2021, &lt;/span&gt;&lt;a href=&quot;mailto:plcl@users.sf.net?subject=VMPK&quot;&gt;&lt;span style=&quot; font-family:&apos;Sans Serif&apos;; text-decoration: underline; color:#0057ae;&quot;&gt;Pedro Lopez-Cabanillas &amp;lt;plcl@users.sf.net&amp;gt;&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;;&quot;&gt;This program is free software; you can redistribute it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;;&quot;&gt;This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;;&quot;&gt;You should have received a copy of the GNU General Public License along with this program; if not, see &lt;/span&gt;&lt;a href=&quot;https://www.gnu.org/licenses/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#007af4;&quot;&gt;https://www.gnu.org/licenses/&lt;/span&gt;&lt;/a&gt;&lt;span style=&quot; font-family:&apos;DejaVu Sans&apos;;&quot;&gt;.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrumGrid</name>
    <message>
        <source>Rows:</source>
        <translation type="unfinished">Lignes&#xa0;:</translation>
    </message>
    <message>
        <source>Use this button to add new rows (sounds) to the current pattern definition</source>
        <translation type="unfinished">Utilisez ce bouton pour ajouter de nouvelles lignes (sons) à la définition actuelle de figure rythmique</translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished">Ajouter</translation>
    </message>
    <message>
        <source>Use this button to remove the selected row (sound) from the pattern definition</source>
        <translation type="unfinished">Utilisez ce bouton pour supprimer la ligne (le son) sélectionnée de la figure rythmique</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished">Retirer</translation>
    </message>
    <message>
        <source>Beats:</source>
        <translation type="unfinished">Notes&#xa0;:</translation>
    </message>
    <message>
        <source>Highligh the grid columns while playing</source>
        <translation type="unfinished">Met les colonnes de la grille en surbrillance durant la lecture</translation>
    </message>
    <message>
        <source>Highlight
Columns</source>
        <translation type="unfinished">Mettre les colonnes
en surbrillance</translation>
    </message>
    <message>
        <source>This is the current beat number</source>
        <translation type="unfinished">Numéro de battement actuel</translation>
    </message>
    <message>
        <source>Pattern:</source>
        <translation type="unfinished">Figure&#xa0;:</translation>
    </message>
    <message>
        <source>Type a new name and press the &quot;Save&quot; button to create a new pattern, or choose an existing pattern from the drop-down list.</source>
        <translation type="unfinished">Saisissez un nouveau nom et cliquez sur le bouton «&#xa0;Enregistrer&#xa0;» pour créer une nouvelle figure rythmique, ou choisissez une figure existante dans la liste déroulante.</translation>
    </message>
    <message>
        <source>This button stores the current pattern definition with the name given</source>
        <translation type="unfinished">Ce bouton enregistre la figure actuelle avec le nom indiqué</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished">Enregistrer</translation>
    </message>
    <message>
        <source>This button deletes the current pattern definition</source>
        <translation type="unfinished">Ce bouton supprime la définition actuelle de figure</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">Supprimer</translation>
    </message>
    <message>
        <source>Number of beats per measure (bar)</source>
        <translation type="unfinished">Nombre de battements par mesure</translation>
    </message>
    <message>
        <source>This is the beat length for the pattern column.</source>
        <translation type="unfinished">Durée du battement pour cette colonne de la figure</translation>
    </message>
    <message>
        <source>Whole</source>
        <translation type="obsolete">Ronde</translation>
    </message>
    <message>
        <source>Half</source>
        <translation type="obsolete">Blanche</translation>
    </message>
    <message>
        <source>Quarter</source>
        <translation type="obsolete">Noire</translation>
    </message>
    <message>
        <source>Eighth</source>
        <translation type="obsolete">Croche</translation>
    </message>
    <message>
        <source>Sixteenth</source>
        <translation type="obsolete">Double croche</translation>
    </message>
    <message>
        <source>Thirty-Second</source>
        <translation type="obsolete">Triple croche</translation>
    </message>
    <message>
        <source>Sixty-Fourth</source>
        <translation type="obsolete">Quadruple croche</translation>
    </message>
    <message>
        <source>This button starts playing the current pattern</source>
        <translation type="unfinished">Démarre la lecture de la figure rythmique</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished">Lire</translation>
    </message>
    <message>
        <source>This button stops the playback</source>
        <translation type="unfinished">Interrompt la lecture</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished">Stop</translation>
    </message>
    <message>
        <source>QPM: quarters per minute</source>
        <translation type="unfinished">Tempo (en noires par minute)</translation>
    </message>
    <message>
        <source>QPM:</source>
        <comment>Quarters per Minute</comment>
        <translation type="unfinished">Tempo&#xa0;:</translation>
    </message>
    <message>
        <source>This is the current tempo in quarters per minute</source>
        <translation type="unfinished">Tempo en noires par minute</translation>
    </message>
    <message>
        <source>Drag the slider handle to change the tempo, in quarters per minute</source>
        <translation type="unfinished">Déplacez le curseur pour modifier le tempo, en noires par minutes</translation>
    </message>
    <message>
        <source>This is the pattern table, beats as columns and sounds as rows</source>
        <translation type="unfinished">Table des figures rythmiques, les battements en colonnes et les sons sur les lignes.</translation>
    </message>
    <message>
        <source>Pattern Editor</source>
        <translation type="unfinished">Éditeur de figures rythmiques</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished">
            </translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished">
            </translation>
    </message>
    <message>
        <source>Paste</source>
        <translation type="unfinished">Figures</translation>
    </message>
    <message>
        <source>Remove Pattern</source>
        <translation type="unfinished">Supprimer la figure</translation>
    </message>
    <message>
        <source>Do you want to remove the current pattern?</source>
        <translation type="unfinished">Voulez-vous supprimer la figure actuelle&#xa0;?</translation>
    </message>
    <message>
        <source>Sample Pattern</source>
        <comment>name of an automatically created pattern</comment>
        <translation type="unfinished">Exemple de figure</translation>
    </message>
    <message>
        <source>Insert Pattern Row</source>
        <translation type="unfinished">Insérer une ligne</translation>
    </message>
    <message>
        <source>Drum Key:</source>
        <translation type="unfinished">Touche «&#xa0;tambour&#xa0;»&#xa0;:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please select one, and only one row</source>
        <translation type="unfinished">Veuillez ne sélectionner qu’une seule ligne</translation>
    </message>
    <message>
        <source>Remove Row</source>
        <translation type="unfinished">Supprimer la ligne</translation>
    </message>
    <message>
        <source>Do you want to remove the selected pattern row?</source>
        <translation type="unfinished">Voulez-vous supprimer la figure rythmique de cette ligne&#xa0;?</translation>
    </message>
</context>
<context>
    <name>HelpWindow</name>
    <message>
        <source>&amp;Home</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom Out</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KMetroPreferences</name>
    <message>
        <source>Preferences</source>
        <translation type="unfinished">Préférences</translation>
    </message>
</context>
<context>
    <name>KMetroPreferencesBase</name>
    <message>
        <source>If this checkbox is activated, the the program will remember the connections for the input and output ports, and try to reconnect them at program startup.</source>
        <translation type="unfinished">Si cette case est cochée, l&apos;application se souviendra des connexions aux ports d&apos;entrées et sorties et tentera de s&apos;y reconnecter au prochain démarrage.</translation>
    </message>
    <message>
        <source>Automatic ports connection on startup</source>
        <translation type="unfinished">Connexion automatique des ports au démarrage</translation>
    </message>
    <message>
        <source>Optional input port conn:</source>
        <translation type="unfinished">Connexion (optionnelle) du port d&apos;entrée&#xa0;:</translation>
    </message>
    <message>
        <source>This is the optional connection for the MIDI IN port.</source>
        <translation type="unfinished">Connexion optionnelle du port d’entrée MIDI.</translation>
    </message>
    <message>
        <source>Output port connection:</source>
        <translation type="unfinished">Connexion du port de sortie&#xa0;:</translation>
    </message>
    <message>
        <source>This is the mandatory connection for the MIDI OUT port</source>
        <translation type="unfinished">Connexion obligatoire du port MIDI de  sortie</translation>
    </message>
    <message>
        <source>Output instrument:</source>
        <translation type="unfinished">Instrument de sortie&#xa0;:</translation>
    </message>
    <message>
        <source>This is the definition of the instrument connected to the MIDI OUT port</source>
        <translation type="unfinished">Définition de l’instrument relié au port MIDI de sortie</translation>
    </message>
    <message>
        <source>Bank:</source>
        <translation type="unfinished">Banque&#xa0;:</translation>
    </message>
    <message>
        <source>This is the Bank of the selected MIDI program</source>
        <translation type="unfinished">Banque du programme MIDI sélectionné</translation>
    </message>
    <message>
        <source>Channel:</source>
        <translation type="unfinished">Canal&#xa0;:</translation>
    </message>
    <message>
        <source>This is the MIDI channel, between 1 and 16. 
General MIDI uses the channel 10 for percussion sounds.</source>
        <translation type="unfinished">Canal MIDI, entre 1 et 16.
Le programme «&#xa0;General&#xa0;» utilise le canal 10 pour les sons de percussion.</translation>
    </message>
    <message>
        <source>Program:</source>
        <translation type="unfinished">Programme&#xa0;:</translation>
    </message>
    <message>
        <source>This is the MIDI program</source>
        <translation type="unfinished">Programme MIDI</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="unfinished">Résolution&#xa0;:</translation>
    </message>
    <message>
        <source>This is the MIDI time resolution (number of ticks in a quarter note)</source>
        <translation type="unfinished">Résolution MIDI (nombre de tics pour une noire)</translation>
    </message>
    <message>
        <source>Weak note:</source>
        <translation type="unfinished">Note du temps faible&#xa0;:</translation>
    </message>
    <message>
        <source>This is the sound of the weak notes for the automatic patterns</source>
        <translation type="unfinished">Son pour la note faible des figures rythmiques automatiques</translation>
    </message>
    <message>
        <source>Note duration:</source>
        <translation type="unfinished">Durée d&apos;une note&#xa0;:</translation>
    </message>
    <message>
        <source>This is the note duration in ticks, when using NOTE OFF events</source>
        <translation type="unfinished">Durée d’une note, en nombre de tics d’horloge, lorsque vous utilisez les événements NOTE OFF</translation>
    </message>
    <message>
        <source>Strong note:</source>
        <translation type="unfinished">Note du temps fort&#xa0;:</translation>
    </message>
    <message>
        <source>This is the sound of the strong notes for the automatic patterns</source>
        <translation type="unfinished">Son pour le temps fort des figures rythmiques automatiques</translation>
    </message>
    <message>
        <source>Optional setting to send NOTE OFF events</source>
        <translation type="unfinished">Envoyer des évènements «&#xa0;NOTE OFF&#xa0;» (facultatif)</translation>
    </message>
    <message>
        <source>Send NOTE OFF events</source>
        <translation type="unfinished">Envoyer des évènements «&#xa0;NOTE OFF&#xa0;»</translation>
    </message>
    <message>
        <source>Forced Dark Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Internal Icon Theme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Qt Style:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KMetronome</name>
    <message>
        <source>Fatal error from the ALSA sequencer. This usually happens when the kernel doesn&apos;t have ALSA support, or the device node (/dev/snd/seq) doesn&apos;t exists, or the kernel module (snd_seq) is not loaded. Please check your ALSA/MIDI configuration. Returned error was: %1</source>
        <translation type="unfinished">Erreur fatale du séquenceur ALSA. Cela arrive généralement lorsque le noyau ne gère pas ALSA, ou lorsque le fichier «&#xa0;/dev/snd/seq&#xa0;» n&apos;existe pas, ou lorsque le module noyau «&#xa0;snd_seq&#xa0;» n&apos;est pas chargé. Veuillez vérifier la configuration de ALSA/MIDI. Le nº d&apos;erreur retourné est&#xa0;: %1</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Erreur</translation>
    </message>
    <message>
        <source>Import Patterns</source>
        <translation type="unfinished">Importer des figures</translation>
    </message>
    <message>
        <source>Pattern Files (*.pat)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export Patterns</source>
        <translation type="unfinished">Exporter des figures</translation>
    </message>
    <message>
        <source>Tempo</source>
        <translation type="unfinished">Tempo</translation>
    </message>
    <message>
        <source>Enter new Tempo:</source>
        <translation type="unfinished">Saisissez le nouveau tempo&#xa0;:</translation>
    </message>
    <message>
        <source>Automatic</source>
        <comment>the pattern is created automatically</comment>
        <translation type="unfinished">Automatique</translation>
    </message>
    <message>
        <source>Language Changed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The language for this application is going to change to %1. Do you want to continue?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KMetronomeWindow</name>
    <message>
        <source>Drumstick Metronome</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This button starts playing the rhythm pattern</source>
        <translation type="unfinished">Démarre la lecture du motif rythmique</translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished">Lire</translation>
    </message>
    <message>
        <source>This button stops playing the rhythm pattern</source>
        <translation type="unfinished">Arrête la lecture du motif rythmique</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished">Stop</translation>
    </message>
    <message>
        <source>This button opens the configuration window</source>
        <translation type="unfinished">Affiche la fenêtre de configuration</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished">Configuration</translation>
    </message>
    <message>
        <source>This button opens the pattern editor</source>
        <translation type="unfinished">Ce bouton ouvre l’éditeur de figures rythmiques</translation>
    </message>
    <message>
        <source>Patterns</source>
        <translation type="unfinished">Figures</translation>
    </message>
    <message>
        <source>This button exits the program</source>
        <translation type="unfinished">Quitte le programme</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation type="unfinished">Quitter</translation>
    </message>
    <message>
        <source>Number of measures (bars) and beats played from beginning</source>
        <translation type="unfinished">Nombre de mesures et de notes jouées depuis le début</translation>
    </message>
    <message>
        <source>Pattern:</source>
        <translation type="unfinished">Figure&#xa0;:</translation>
    </message>
    <message>
        <source>This is the pattern definition to play, either &quot;Automatic&quot; or a custom defined one.</source>
        <translation type="unfinished">Définition de la figure à jouer, «&#xa0;automatique&#xa0;» ou personnalisée.</translation>
    </message>
    <message>
        <source>Beats/Bar:</source>
        <translation type="unfinished">Notes par mesure&#xa0;:</translation>
    </message>
    <message>
        <source>This is the number of beats for each measure (bar).
Values are from 1 to 32.
It is the numerator of the time signature specification.</source>
        <translation type="unfinished">Nombre de temps dans une mesure
Les valeurs vont de 1 à 32.
C’est le numérateur de la signature rythmique.</translation>
    </message>
    <message>
        <source>Beat Length:</source>
        <translation type="unfinished">Durée de la note&#xa0;:</translation>
    </message>
    <message>
        <source>This is the beat length.
Values mean 1, 2, 4, 8, 16, 32 and 64.
It is the denominator in the time signature specification.</source>
        <translation type="unfinished">Durée de la note.
Les valeurs sont 1, 2, 4, 8, 16, 32 et 64.
C&apos;est le dénominateur de la signature rythmique.</translation>
    </message>
    <message>
        <source>Whole</source>
        <translation type="obsolete">Ronde</translation>
    </message>
    <message>
        <source>Half</source>
        <translation type="obsolete">Blanche</translation>
    </message>
    <message>
        <source>Quarter</source>
        <translation type="obsolete">Noire</translation>
    </message>
    <message>
        <source>Eighth</source>
        <translation type="obsolete">Croche</translation>
    </message>
    <message>
        <source>Sixteenth</source>
        <translation type="obsolete">Double croche</translation>
    </message>
    <message>
        <source>Thirty-Second</source>
        <translation type="obsolete">Triple croche</translation>
    </message>
    <message>
        <source>Sixty-Fourth</source>
        <translation type="obsolete">Quadruple croche</translation>
    </message>
    <message>
        <source>Weak</source>
        <comment>weak notes MIDI velocity</comment>
        <translation type="unfinished">Faible</translation>
    </message>
    <message>
        <source>Strong</source>
        <comment>strong notes MIDI velocity</comment>
        <translation type="unfinished">Fort</translation>
    </message>
    <message>
        <source>Volume</source>
        <comment>audio volume level</comment>
        <translation type="unfinished">Volume</translation>
    </message>
    <message>
        <source>Pan</source>
        <comment>audio panning</comment>
        <translation type="unfinished">Balance</translation>
    </message>
    <message>
        <source>This is the velocity of the weak notes in the automatic rhythm pattern (all of them, except the first one)</source>
        <translation type="unfinished">Intensité des temps faibles dans la figure rythmique (toutes les notes sauf la première)</translation>
    </message>
    <message>
        <source>This is the velocity of the strong note in the automatic rhythm pattern (the first one)</source>
        <translation type="unfinished">Intensité du temps fort dans la figure rythmique (la première note)</translation>
    </message>
    <message>
        <source>This is the MIDI volume control (CC7)</source>
        <translation type="unfinished">Contrôle du volume MIDI (CC7)</translation>
    </message>
    <message>
        <source>This is the MIDI pan control (CC10)</source>
        <translation type="unfinished">Contrôle de la balance MIDI (CC10)</translation>
    </message>
    <message>
        <source>This is the musical name of the tempo value</source>
        <translation type="unfinished">Nom musical de la valeur du tempo</translation>
    </message>
    <message>
        <source>The current &lt;i&gt;tempo&lt;/i&gt; value</source>
        <translation type="unfinished">Valeur actuelle du &lt;i&gt;tempo&lt;/i&gt;</translation>
    </message>
    <message>
        <source>Tempo (in quarters per minute)</source>
        <translation type="unfinished">Tempo (en noires par minute)&#xa0;:</translation>
    </message>
    <message>
        <source>This slider changes the &lt;i&gt;tempo&lt;/i&gt;, or speed of the rhythm.
Values are 25 to 250 quarters per minute (&lt;i&gt;Maelzel Metronome units&lt;/i&gt;).</source>
        <translation type="unfinished">Ce curseur modifie le &lt;i&gt;tempo&lt;/i&gt;, ou la vitesse du rythme.
Les valeurs possibles vont de 25 à 250 noires par minute (&lt;i&gt;unités du métronome de Maelzel&lt;/i&gt;)</translation>
    </message>
    <message>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>language</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>toolBar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Patterns</source>
        <translation type="unfinished">Importer des figures</translation>
    </message>
    <message>
        <source>Export Patterns</source>
        <translation type="unfinished">Exporter des figures</translation>
    </message>
    <message>
        <source>Play/Stop</source>
        <translation type="unfinished">Lire/Stop</translation>
    </message>
    <message>
        <source>Edit Patterns</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>about</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Action Buttons</source>
        <translation type="unfinished">Afficher les boutons d’action</translation>
    </message>
    <message>
        <source>Show Toolbar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>about Qt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Help Contents</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>Whole</source>
        <translation type="unfinished">Ronde</translation>
    </message>
    <message>
        <source>Half</source>
        <translation type="unfinished">Blanche</translation>
    </message>
    <message>
        <source>Quarter</source>
        <translation type="unfinished">Noire</translation>
    </message>
    <message>
        <source>Eight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sixteenth</source>
        <translation type="unfinished">Double croche</translation>
    </message>
    <message>
        <source>Thirty-Second</source>
        <translation type="unfinished">Triple croche</translation>
    </message>
    <message>
        <source>Sixty-Fourth</source>
        <translation type="unfinished">Quadruple croche</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Cakewalk Instrument Definition File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SequencerAdapter</name>
    <message>
        <source>No connection</source>
        <translation type="unfinished">Pas de connexion</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:101</name>
    <message>
        <source>Drag the slider handle to change the tempo, in quarters per minute</source>
        <translation type="vanished">Déplacez le curseur pour modifier le tempo, en noires par minutes</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:104</name>
    <message>
        <source>MIDI Metronome</source>
        <translation type="vanished">Métronome MIDI</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:107</name>
    <message>
        <source>This button starts playing the rhythm pattern</source>
        <translation type="vanished">Démarre la lecture du motif rythmique</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:110</name>
    <message>
        <source>Play</source>
        <translation type="vanished">Lire</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:113</name>
    <message>
        <source>This button stops playing the rhythm pattern</source>
        <translation type="vanished">Arrête la lecture du motif rythmique</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:116</name>
    <message>
        <source>Stop</source>
        <translation type="vanished">Stop</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:119</name>
    <message>
        <source>This button opens the configuration window</source>
        <translation type="vanished">Affiche la fenêtre de configuration</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:12</name>
    <message>
        <source>Save</source>
        <translation type="vanished">Enregistrer</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:122</name>
    <message>
        <source>Settings</source>
        <translation type="vanished">Configuration</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:125</name>
    <message>
        <source>This button opens the pattern editor</source>
        <translation type="vanished">Ce bouton ouvre l’éditeur de figures rythmiques</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:128</name>
    <message>
        <source>Patterns</source>
        <translation type="vanished">Figures</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:131</name>
    <message>
        <source>This button exits the program</source>
        <translation type="vanished">Quitte le programme</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:134</name>
    <message>
        <source>Quit</source>
        <translation type="vanished">Quitter</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:137</name>
    <message>
        <source>Number of measures (bars) and beats played from beginning</source>
        <translation type="vanished">Nombre de mesures et de notes jouées depuis le début</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:140</name>
    <message>
        <source>Pattern:</source>
        <translation type="vanished">Figure&#xa0;:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:143</name>
    <message>
        <source>This is the pattern definition to play, either &quot;Automatic&quot; or a custom defined one.</source>
        <translation type="vanished">Définition de la figure à jouer, «&#xa0;automatique&#xa0;» ou personnalisée.</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:146</name>
    <message>
        <source>Beats/Bar:</source>
        <translation type="vanished">Notes par mesure&#xa0;:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:149</name>
    <message>
        <source>This is the number of beats for each measure (bar).
Values are from 1 to 32.
It is the numerator of the time signature specification.</source>
        <translation type="vanished">Nombre de temps dans une mesure
Les valeurs vont de 1 à 32.
C’est le numérateur de la signature rythmique.</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:15</name>
    <message>
        <source>This button deletes the current pattern definition</source>
        <translation type="vanished">Ce bouton supprime la définition actuelle de figure</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:154</name>
    <message>
        <source>Beat Length:</source>
        <translation type="vanished">Durée de la note&#xa0;:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:157</name>
    <message>
        <source>This is the beat length.
Values mean 1, 2, 4, 8, 16, 32 and 64.
It is the denominator in the time signature specification.</source>
        <translation type="vanished">Durée de la note.
Les valeurs sont 1, 2, 4, 8, 16, 32 et 64.
C&apos;est le dénominateur de la signature rythmique.</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:162</name>
    <message>
        <source>Whole</source>
        <translation type="vanished">Ronde</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:165</name>
    <message>
        <source>Half</source>
        <translation type="vanished">Blanche</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:168</name>
    <message>
        <source>Quarter</source>
        <translation type="vanished">Noire</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:171</name>
    <message>
        <source>Eighth</source>
        <translation type="vanished">Croche</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:174</name>
    <message>
        <source>Sixteenth</source>
        <translation type="vanished">Double croche</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:177</name>
    <message>
        <source>Thirty-Second</source>
        <translation type="vanished">Triple croche</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:18</name>
    <message>
        <source>Delete</source>
        <translation type="vanished">Supprimer</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:180</name>
    <message>
        <source>Sixty-Fourth</source>
        <translation type="vanished">Quadruple croche</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:183</name>
    <message>
        <source>Weak</source>
        <translation type="vanished">Faible</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:186</name>
    <message>
        <source>Strong</source>
        <translation type="vanished">Fort</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:189</name>
    <message>
        <source>Volume</source>
        <translation type="vanished">Volume</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:192</name>
    <message>
        <source>Pan</source>
        <translation type="vanished">Balance</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:195</name>
    <message>
        <source>This is the velocity of the weak notes in the automatic rhythm pattern (all of them, except the first one)</source>
        <translation type="vanished">Intensité des temps faibles dans la figure rythmique (toutes les notes sauf la première)</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:198</name>
    <message>
        <source>This is the velocity of the strong note in the automatic rhythm pattern (the first one)</source>
        <translation type="vanished">Intensité du temps fort dans la figure rythmique (la première note)</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:201</name>
    <message>
        <source>This is the MIDI volume control (CC7)</source>
        <translation type="vanished">Contrôle du volume MIDI (CC7)</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:204</name>
    <message>
        <source>This is the MIDI pan control (CC10)</source>
        <translation type="vanished">Contrôle de la balance MIDI (CC10)</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:207</name>
    <message>
        <source>This is the musical name of the tempo value</source>
        <translation type="vanished">Nom musical de la valeur du tempo</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:21</name>
    <message>
        <source>Rows:</source>
        <translation type="vanished">Lignes&#xa0;:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:210</name>
    <message>
        <source>The current &lt;i&gt;tempo&lt;/i&gt; value</source>
        <translation type="vanished">Valeur actuelle du &lt;i&gt;tempo&lt;/i&gt;</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:213</name>
    <message>
        <source>Tempo (in quarters per minute)</source>
        <translation type="vanished">Tempo (en noires par minute)&#xa0;:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:216</name>
    <message>
        <source>This slider changes the &lt;i&gt;tempo&lt;/i&gt;, or speed of the rhythm.
Values are 25 to 250 quarters per minute (&lt;i&gt;Maelzel Metronome units&lt;/i&gt;).</source>
        <translation type="vanished">Ce curseur modifie le &lt;i&gt;tempo&lt;/i&gt;, ou la vitesse du rythme.
Les valeurs possibles vont de 25 à 250 noires par minute (&lt;i&gt;unités du métronome de Maelzel&lt;/i&gt;)</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:220</name>
    <message>
        <source>If this checkbox is activated, the the program will remember the connections for the input and output ports, and try to reconnect them at program startup.</source>
        <translation type="vanished">Si cette case est cochée, l&apos;application se souviendra des connexions aux ports d&apos;entrées et sorties et tentera de s&apos;y reconnecter au prochain démarrage.</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:223</name>
    <message>
        <source>Automatic ports connection on startup</source>
        <translation type="vanished">Connexion automatique des ports au démarrage</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:226</name>
    <message>
        <source>Optional input port conn:</source>
        <translation type="vanished">Connexion (optionnelle) du port d&apos;entrée&#xa0;:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:229</name>
    <message>
        <source>This is the optional connection for the MIDI IN port.</source>
        <translation type="vanished">Connexion optionnelle du port d’entrée MIDI.</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:232</name>
    <message>
        <source>Output port connection:</source>
        <translation type="vanished">Connexion du port de sortie&#xa0;:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:235</name>
    <message>
        <source>This is the mandatory connection for the MIDI OUT port</source>
        <translation type="vanished">Connexion obligatoire du port MIDI de  sortie</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:238</name>
    <message>
        <source>Output instrument:</source>
        <translation type="vanished">Instrument de sortie&#xa0;:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:24</name>
    <message>
        <source>Use this button to add new rows (sounds) to the current pattern definition</source>
        <translation type="vanished">Utilisez ce bouton pour ajouter de nouvelles lignes (sons) à la définition actuelle de figure rythmique</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:241</name>
    <message>
        <source>This is the definition of the instrument connected to the MIDI OUT port</source>
        <translation type="vanished">Définition de l’instrument relié au port MIDI de sortie</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:244</name>
    <message>
        <source>Bank:</source>
        <translation type="vanished">Banque&#xa0;:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:247</name>
    <message>
        <source>This is the Bank of the selected MIDI program</source>
        <translation type="vanished">Banque du programme MIDI sélectionné</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:250</name>
    <message>
        <source>Channel:</source>
        <translation type="vanished">Canal&#xa0;:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:253</name>
    <message>
        <source>This is the MIDI channel, between 1 and 16. 
General MIDI uses the channel 10 for percussion sounds.</source>
        <translation type="vanished">Canal MIDI, entre 1 et 16.
Le programme «&#xa0;General&#xa0;» utilise le canal 10 pour les sons de percussion.</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:257</name>
    <message>
        <source>Program:</source>
        <translation type="vanished">Programme&#xa0;:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:260</name>
    <message>
        <source>This is the MIDI program</source>
        <translation type="vanished">Programme MIDI</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:263</name>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">Résolution&#xa0;:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:266</name>
    <message>
        <source>This is the MIDI time resolution (number of ticks in a quarter note)</source>
        <translation type="vanished">Résolution MIDI (nombre de tics pour une noire)</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:269</name>
    <message>
        <source>Weak note:</source>
        <translation type="vanished">Note du temps faible&#xa0;:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:27</name>
    <message>
        <source>Add</source>
        <translation type="vanished">Ajouter</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:272</name>
    <message>
        <source>This is the sound of the weak notes for the automatic patterns</source>
        <translation type="vanished">Son pour la note faible des figures rythmiques automatiques</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:275</name>
    <message>
        <source>Note duration:</source>
        <translation type="vanished">Durée d&apos;une note&#xa0;:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:278</name>
    <message>
        <source>This is the note duration in ticks, when using NOTE OFF events</source>
        <translation type="vanished">Durée d’une note, en nombre de tics d’horloge, lorsque vous utilisez les événements NOTE OFF</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:281</name>
    <message>
        <source>Strong note:</source>
        <translation type="vanished">Note du temps fort&#xa0;:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:284</name>
    <message>
        <source>This is the sound of the strong notes for the automatic patterns</source>
        <translation type="vanished">Son pour le temps fort des figures rythmiques automatiques</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:287</name>
    <message>
        <source>Optional setting to send NOTE OFF events</source>
        <translation type="vanished">Envoyer des évènements «&#xa0;NOTE OFF&#xa0;» (facultatif)</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:290</name>
    <message>
        <source>Send NOTE OFF events</source>
        <translation type="vanished">Envoyer des évènements «&#xa0;NOTE OFF&#xa0;»</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:293</name>
    <message>
        <source>If this option is activated, the knobs are drawn using a custom style</source>
        <translation type="vanished">Si cette option est activée, les boutons seront affichés avec un style personnalisé</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:296</name>
    <message>
        <source>Styled Knobs</source>
        <translation type="vanished">Jolis boutons</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:297</name>
    <message>
        <source>Your names</source>
        <translation type="vanished">Julien Richard-Foy</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:298</name>
    <message>
        <source>Your emails</source>
        <translation type="vanished">julien.rf@no-log.org</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:3</name>
    <message>
        <source>Pattern:</source>
        <translation type="vanished">Figure&#xa0;:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:30</name>
    <message>
        <source>Use this button to remove the selected row (sound) from the pattern definition</source>
        <translation type="vanished">Utilisez ce bouton pour supprimer la ligne (le son) sélectionnée de la figure rythmique</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:33</name>
    <message>
        <source>Remove</source>
        <translation type="vanished">Retirer</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:36</name>
    <message>
        <source>Beats:</source>
        <translation type="vanished">Notes&#xa0;:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:39</name>
    <message>
        <source>Highligh the grid columns while playing</source>
        <translation type="vanished">Met les colonnes de la grille en surbrillance durant la lecture</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:42</name>
    <message>
        <source>Highlight
Columns</source>
        <translation type="vanished">Mettre les colonnes
en surbrillance</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:46</name>
    <message>
        <source>This is the current beat number</source>
        <translation type="vanished">Numéro de battement actuel</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:49</name>
    <message>
        <source>This is the pattern table, beats as columns and sounds as rows</source>
        <translation type="vanished">Table des figures rythmiques, les battements en colonnes et les sons sur les lignes.</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:52</name>
    <message>
        <source>Number of beats per measure (bar)</source>
        <translation type="vanished">Nombre de battements par mesure</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:55</name>
    <message>
        <source>This is the beat length for the pattern column.</source>
        <translation type="vanished">Durée du battement pour cette colonne de la figure</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:58</name>
    <message>
        <source>Whole</source>
        <translation type="vanished">Ronde</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:6</name>
    <message>
        <source>Type a new name and press the &quot;Save&quot; button to create a new pattern, or choose an existing pattern from the drop-down list.</source>
        <translation type="vanished">Saisissez un nouveau nom et cliquez sur le bouton «&#xa0;Enregistrer&#xa0;» pour créer une nouvelle figure rythmique, ou choisissez une figure existante dans la liste déroulante.</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:61</name>
    <message>
        <source>Half</source>
        <translation type="vanished">Blanche</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:64</name>
    <message>
        <source>Quarter</source>
        <translation type="vanished">Noire</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:67</name>
    <message>
        <source>Eighth</source>
        <translation type="vanished">Croche</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:70</name>
    <message>
        <source>Sixteenth</source>
        <translation type="vanished">Double croche</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:73</name>
    <message>
        <source>Thirty-Second</source>
        <translation type="vanished">Triple croche</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:76</name>
    <message>
        <source>Sixty-Fourth</source>
        <translation type="vanished">Quadruple croche</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:79</name>
    <message>
        <source>This button starts playing the current pattern</source>
        <translation type="vanished">Démarre la lecture de la figure rythmique</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:82</name>
    <message>
        <source>Play</source>
        <translation type="vanished">Lire</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:85</name>
    <message>
        <source>This button stops the playback</source>
        <translation type="vanished">Interrompt la lecture</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:88</name>
    <message>
        <source>Stop</source>
        <translation type="vanished">Stop</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:9</name>
    <message>
        <source>This button stores the current pattern definition with the name given</source>
        <translation type="vanished">Ce bouton enregistre la figure actuelle avec le nom indiqué</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:91</name>
    <message>
        <source>QPM: quarters per minute</source>
        <translation type="vanished">Tempo (en noires par minute)</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:94</name>
    <message>
        <source>QPM:</source>
        <translation type="vanished">Tempo&#xa0;:</translation>
    </message>
</context>
<context>
    <name>po/rc.cpp:97</name>
    <message>
        <source>This is the current tempo in quarters per minute</source>
        <translation type="vanished">Tempo en noires par minute</translation>
    </message>
</context>
<context>
    <name>src/drumgrid.cpp:278</name>
    <message>
        <source>Do you want to remove the current pattern?</source>
        <translation type="vanished">Voulez-vous supprimer la figure actuelle&#xa0;?</translation>
    </message>
</context>
<context>
    <name>src/drumgrid.cpp:279</name>
    <message>
        <source>Remove Pattern</source>
        <translation type="vanished">Supprimer la figure</translation>
    </message>
</context>
<context>
    <name>src/drumgrid.cpp:333</name>
    <message>
        <source>Sample Pattern</source>
        <translation type="vanished">Exemple de figure</translation>
    </message>
</context>
<context>
    <name>src/drumgrid.cpp:364</name>
    <message>
        <source>Insert Pattern Row</source>
        <translation type="vanished">Insérer une ligne</translation>
    </message>
</context>
<context>
    <name>src/drumgrid.cpp:365</name>
    <message>
        <source>Drum Key:</source>
        <translation type="vanished">Touche «&#xa0;tambour&#xa0;»&#xa0;:</translation>
    </message>
</context>
<context>
    <name>src/drumgrid.cpp:386</name>
    <message>
        <source>Please select one, and only one row</source>
        <translation type="vanished">Veuillez ne sélectionner qu’une seule ligne</translation>
    </message>
</context>
<context>
    <name>src/drumgrid.cpp:388</name>
    <message>
        <source>Do you want to remove the selected pattern row?</source>
        <translation type="vanished">Voulez-vous supprimer la figure rythmique de cette ligne&#xa0;?</translation>
    </message>
</context>
<context>
    <name>src/drumgrid.cpp:389</name>
    <message>
        <source>Remove Row</source>
        <translation type="vanished">Supprimer la ligne</translation>
    </message>
</context>
<context>
    <name>src/drumgrid.cpp:51</name>
    <message>
        <source>Pattern Editor</source>
        <translation type="vanished">Éditeur de figures rythmiques</translation>
    </message>
</context>
<context>
    <name>src/drumgrid.cpp:67</name>
    <message>
        <source>Cut</source>
        <translation type="obsolete">
            </translation>
    </message>
</context>
<context>
    <name>src/drumgrid.cpp:68</name>
    <message>
        <source>Copy</source>
        <translation type="obsolete">
            </translation>
    </message>
</context>
<context>
    <name>src/drumgrid.cpp:69</name>
    <message>
        <source>Paste</source>
        <translation type="obsolete">Figures</translation>
    </message>
</context>
<context>
    <name>src/kmetronome.cpp:114</name>
    <message>
        <source>Play/Stop</source>
        <translation type="vanished">Lire/Stop</translation>
    </message>
</context>
<context>
    <name>src/kmetronome.cpp:118</name>
    <message>
        <source>Show Action Buttons</source>
        <translation type="vanished">Afficher les boutons d’action</translation>
    </message>
</context>
<context>
    <name>src/kmetronome.cpp:125</name>
    <message>
        <source>Patterns</source>
        <translation type="vanished">Figures</translation>
    </message>
</context>
<context>
    <name>src/kmetronome.cpp:130</name>
    <message>
        <source>Import Patterns</source>
        <translation type="vanished">Importer des figures</translation>
    </message>
</context>
<context>
    <name>src/kmetronome.cpp:135</name>
    <message>
        <source>Export Patterns</source>
        <translation type="vanished">Exporter des figures</translation>
    </message>
</context>
<context>
    <name>src/kmetronome.cpp:497</name>
    <message>
        <source>*.pat|Pattern Files (*.pat)</source>
        <translation type="vanished">*.pat|Fichiers de figures rythmiques (*.pat)</translation>
    </message>
</context>
<context>
    <name>src/kmetronome.cpp:498</name>
    <message>
        <source>Import Patterns</source>
        <translation type="vanished">Importer des figures</translation>
    </message>
</context>
<context>
    <name>src/kmetronome.cpp:510</name>
    <message>
        <source>*.pat|Pattern Files (*.pat)</source>
        <translation type="vanished">*.pat|Fichiers de figures rythmiques (*.pat)</translation>
    </message>
</context>
<context>
    <name>src/kmetronome.cpp:511</name>
    <message>
        <source>Export Patterns</source>
        <translation type="vanished">Exporter des figures</translation>
    </message>
</context>
<context>
    <name>src/kmetronome.cpp:527</name>
    <message>
        <source>Patterns</source>
        <translation type="vanished">Figures</translation>
    </message>
</context>
<context>
    <name>src/kmetronome.cpp:87</name>
    <message>
        <source>Fatal error from the ALSA sequencer. This usually happens when the kernel doesn&apos;t have ALSA support, or the device node (/dev/snd/seq) doesn&apos;t exists, or the kernel module (snd_seq) is not loaded. Please check your ALSA/MIDI configuration. Returned error was: %1</source>
        <translation type="vanished">Erreur fatale du séquenceur ALSA. Cela arrive généralement lorsque le noyau ne gère pas ALSA, ou lorsque le fichier «&#xa0;/dev/snd/seq&#xa0;» n&apos;existe pas, ou lorsque le module noyau «&#xa0;snd_seq&#xa0;» n&apos;est pas chargé. Veuillez vérifier la configuration de ALSA/MIDI. Le nº d&apos;erreur retourné est&#xa0;: %1</translation>
    </message>
</context>
<context>
    <name>src/kmetronome.cpp:93</name>
    <message>
        <source>Error</source>
        <translation type="vanished">Erreur</translation>
    </message>
</context>
<context>
    <name>src/kmetronomeview.cpp:145</name>
    <message>
        <source>Tempo</source>
        <translation type="vanished">Tempo</translation>
    </message>
    <message>
        <source>Enter new Tempo:</source>
        <translation type="vanished">Saisissez le nouveau tempo&#xa0;:</translation>
    </message>
</context>
<context>
    <name>src/kmetronomeview.cpp:179</name>
    <message>
        <source>Automatic</source>
        <translation type="vanished">Automatique</translation>
    </message>
</context>
<context>
    <name>src/kmetropreferences.cpp:29</name>
    <message>
        <source>Preferences</source>
        <translation type="vanished">Préférences</translation>
    </message>
</context>
<context>
    <name>src/main.cpp:29</name>
    <message>
        <source>KDE MIDI metronome using ALSA sequencer</source>
        <translation type="vanished">Métronome MIDI KDE utilisant le séquenceur ALSA</translation>
    </message>
</context>
<context>
    <name>src/main.cpp:41</name>
    <message>
        <source>KMetronome</source>
        <translation type="vanished">KMetronome</translation>
    </message>
</context>
<context>
    <name>src/main.cpp:43</name>
    <message>
        <source>(C) 2005-2012 Pedro Lopez-Cabanillas</source>
        <translation type="vanished">(C) 2005-2012 Pedro Lopez-Cabanillas</translation>
    </message>
</context>
<context>
    <name>src/main.cpp:45</name>
    <message>
        <source>Pedro Lopez-Cabanillas</source>
        <translation type="vanished">Pedro Lopez-Cabanillas</translation>
    </message>
</context>
<context>
    <name>src/sequenceradapter.cpp:65</name>
    <message>
        <source>No connection</source>
        <translation type="vanished">Pas de connexion</translation>
    </message>
</context>
</TS>
